@@ -1,12 +1,13 @@
-from google.oauth2 import service_account
+import logging
+from uuid import uuid4
 
-from ..fields.encrypted_json import EncryptedJSONField
 from django.db import models
 from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
+from google.oauth2 import service_account
+
+from ..fields.encrypted_json import EncryptedJSONField
 from .mappings import LAST_STATUS_CHOICES, STORAGE_PROVIDER_MAP
-import logging
-from uuid import uuid4
 
 log = logging.getLogger(__name__)
 
@@ -14,9 +15,21 @@ log = logging.getLogger(__name__)
 class AbstractStorageTarget(models.Model):
     """Abstract implementation of a storage target which includes access details for how to interact with the downstream object storage system"""
 
-    id = models.UUIDField(default=uuid4, primary_key=True, help_text=_("UUID identifying this objects"))
-    name = models.CharField(max_length=150, db_index=True, help_text=_("Name of this object"))
-    description = models.TextField(blank=True, null=True, help_text=_("Description of this object"))
+    id = models.UUIDField(
+        default=uuid4,
+        primary_key=True,
+        help_text=_("UUID identifying this objects"),
+    )
+    name = models.CharField(
+        max_length=150,
+        db_index=True,
+        help_text=_("Name of this object"),
+    )
+    description = models.TextField(
+        blank=True,
+        null=True,
+        help_text=_("Description of this object"),
+    )
 
     last_checked = models.DateTimeField(
         null=True,
